import { ConcreteComponent, Data, Component } from './component';
import { ComponentOptions } from './componentOptions';
import { ComponentPublicInstance } from './componentPublicInstance';
import { Directive } from './directives';
import { RootRenderFunction } from './renderer';
import { InjectionKey } from './apiInject';
import { RootHydrateFunction } from './hydration';
export interface App<HostElement = any> {
    version: string;
    config: AppConfig;
    use(plugin: Plugin, ...options: any[]): this;
    mixin(mixin: ComponentOptions): this;
    component(name: string): Component | undefined;
    component(name: string, component: Component): this;
    directive(name: string): Directive | undefined;
    directive(name: string, directive: Directive): this;
    mount(rootContainer: HostElement | string, isHydrate?: boolean): ComponentPublicInstance;
    unmount(rootContainer: HostElement | string): void;
    provide<T>(key: InjectionKey<T> | string, value: T): this;
    _uid: number;
    _component: ConcreteComponent;
    _props: Data | null;
    _container: HostElement | null;
    _context: AppContext;
}
export declare type OptionMergeFunction = (to: unknown, from: unknown, instance: any, key: string) => any;
export interface AppConfig {
    readonly isNativeTag?: (tag: string) => boolean;
    performance: boolean;
    optionMergeStrategies: Record<string, OptionMergeFunction>;
    globalProperties: Record<string, any>;
    isCustomElement: (tag: string) => boolean;
    errorHandler?: (err: unknown, instance: ComponentPublicInstance | null, info: string) => void;
    warnHandler?: (msg: string, instance: ComponentPublicInstance | null, trace: string) => void;
}
export interface AppContext {
    app: App;
    config: AppConfig;
    mixins: ComponentOptions[];
    components: Record<string, Component>;
    directives: Record<string, Directive>;
    provides: Record<string | symbol, any>;
    reload?: () => void;
}
declare type PluginInstallFunction = (app: App, ...options: any[]) => any;
export declare type Plugin = PluginInstallFunction & {
    install?: PluginInstallFunction;
} | {
    install: PluginInstallFunction;
};
export declare function createAppContext(): AppContext;
export declare type CreateAppFunction<HostElement> = (rootComponent: Component, rootProps?: Data | null) => App<HostElement>;
export declare function createAppAPI<HostElement>(render: RootRenderFunction, hydrate?: RootHydrateFunction): CreateAppFunction<HostElement>;
export {};
//# sourceMappingURL=apiCreateApp.d.ts.map