import { ComponentInternalInstance } from '../component';
import { VNode } from '../vnode';
import { RendererElement } from '../renderer';
export interface BaseTransitionProps<HostElement = RendererElement> {
    mode?: 'in-out' | 'out-in' | 'default';
    appear?: boolean;
    persisted?: boolean;
    onBeforeEnter?: (el: HostElement) => void;
    onEnter?: (el: HostElement, done: () => void) => void;
    onAfterEnter?: (el: HostElement) => void;
    onEnterCancelled?: (el: HostElement) => void;
    onBeforeLeave?: (el: HostElement) => void;
    onLeave?: (el: HostElement, done: () => void) => void;
    onAfterLeave?: (el: HostElement) => void;
    onLeaveCancelled?: (el: HostElement) => void;
    onBeforeAppear?: (el: HostElement) => void;
    onAppear?: (el: HostElement, done: () => void) => void;
    onAfterAppear?: (el: HostElement) => void;
    onAppearCancelled?: (el: HostElement) => void;
}
export interface TransitionHooks<HostElement extends RendererElement = RendererElement> {
    mode: BaseTransitionProps['mode'];
    persisted: boolean;
    beforeEnter(el: HostElement): void;
    enter(el: HostElement): void;
    leave(el: HostElement, remove: () => void): void;
    clone(vnode: VNode): TransitionHooks<HostElement>;
    afterLeave?(): void;
    delayLeave?(el: HostElement, earlyRemove: () => void, delayedLeave: () => void): void;
    delayedLeave?(): void;
}
export declare type PendingCallback = (cancelled?: boolean) => void;
export interface TransitionState {
    isMounted: boolean;
    isLeaving: boolean;
    isUnmounting: boolean;
    leavingVNodes: Map<any, Record<string, VNode>>;
}
export interface TransitionElement {
    _enterCb?: PendingCallback;
    _leaveCb?: PendingCallback;
}
export declare function useTransitionState(): TransitionState;
export declare const BaseTransition: new () => {
    $props: BaseTransitionProps<any>;
};
export declare function resolveTransitionHooks(vnode: VNode, props: BaseTransitionProps<any>, state: TransitionState, instance: ComponentInternalInstance): TransitionHooks;
export declare function setTransitionHooks(vnode: VNode, hooks: TransitionHooks): void;
export declare function getTransitionRawChildren(children: VNode[], keepComment?: boolean): VNode[];
//# sourceMappingURL=BaseTransition.d.ts.map