export interface SchedulerJob {
    (): void;
    /**
     * unique job id, only present on raw effects, e.g. component render effect
     */
    id?: number;
    /**
     * Indicates whether the job is allowed to recursively trigger itself.
     * By default, a job cannot trigger itself because some built-in method calls,
     * e.g. Array.prototype.push actually performs reads as well (#1740) which
     * can lead to confusing infinite loops.
     * The allowed cases are component update functions and watch callbacks.
     * Component update functions may update child component props, which in turn
     * trigger flush: "pre" watch callbacks that mutates state that the parent
     * relies on (#1801). Watch callbacks doesn't track its dependencies so if it
     * triggers itself again, it's likely intentional and it is the user's
     * responsibility to perform recursive state mutation that eventually
     * stabilizes (#1727).
     */
    allowRecurse?: boolean;
}
export declare type SchedulerCb = Function & {
    id?: number;
};
export declare type SchedulerCbs = SchedulerCb | SchedulerCb[];
declare type CountMap = Map<SchedulerJob | SchedulerCb, number>;
export declare function cleanAllJobs(): void;
export declare function nextTick(fn?: () => void): Promise<void>;
export declare function queueJob(job: SchedulerJob): void;
export declare function invalidateJob(job: SchedulerJob): void;
export declare function queuePreFlushCb(cb: SchedulerCb): void;
export declare function queuePostFlushCb(cb: SchedulerCbs): void;
export declare function flushPreFlushCbs(seen?: CountMap, parentJob?: SchedulerJob | null): void;
export declare function flushPostFlushCbs(seen?: CountMap): void;
export {};
//# sourceMappingURL=scheduler.d.ts.map