import { ComponentInternalInstance, Data, ClassComponent, Component } from './component';
import { RawSlots } from './componentSlots';
import { Ref, ReactiveFlags } from '@atom-vue/reactivity';
import { AppContext } from './apiCreateApp';
import { SuspenseImpl, SuspenseBoundary } from './components/Suspense';
import { DirectiveBinding } from './directives';
import { TransitionHooks } from './components/BaseTransition';
import { TeleportImpl } from './components/Teleport';
import { RendererNode, RendererElement } from './renderer';
import { NULL_DYNAMIC_COMPONENT } from './helpers/resolveAssets';
export declare const Fragment: {
    new (): {
        $props: VNodeProps;
    };
    __isFragment: true;
};
export declare const Text: unique symbol;
export declare const Comment: unique symbol;
export declare const Static: unique symbol;
export declare type VNodeTypes = string | VNode | Component | typeof Text | typeof Static | typeof Comment | typeof Fragment | typeof TeleportImpl | typeof SuspenseImpl;
export declare type VNodeRef = string | Ref | ((ref: object | null, refs: Record<string, any>) => void);
export declare type VNodeNormalizedRefAtom = {
    i: ComponentInternalInstance;
    r: VNodeRef;
};
export declare type VNodeNormalizedRef = VNodeNormalizedRefAtom | (VNodeNormalizedRefAtom)[];
declare type VNodeMountHook = (vnode: VNode) => void;
declare type VNodeUpdateHook = (vnode: VNode, oldVNode: VNode) => void;
export declare type VNodeHook = VNodeMountHook | VNodeUpdateHook | VNodeMountHook[] | VNodeUpdateHook[];
export declare type VNodeProps = {
    key?: string | number;
    ref?: VNodeRef;
    onVnodeBeforeMount?: VNodeMountHook | VNodeMountHook[];
    onVnodeMounted?: VNodeMountHook | VNodeMountHook[];
    onVnodeBeforeUpdate?: VNodeUpdateHook | VNodeUpdateHook[];
    onVnodeUpdated?: VNodeUpdateHook | VNodeUpdateHook[];
    onVnodeBeforeUnmount?: VNodeMountHook | VNodeMountHook[];
    onVnodeUnmounted?: VNodeMountHook | VNodeMountHook[];
};
declare type VNodeChildAtom = VNode | string | number | boolean | null | undefined | void;
export declare type VNodeArrayChildren = Array<VNodeArrayChildren | VNodeChildAtom>;
export declare type VNodeChild = VNodeChildAtom | VNodeArrayChildren;
export declare type VNodeNormalizedChildren = string | VNodeArrayChildren | RawSlots | null;
export interface VNode<HostNode = RendererNode, HostElement = RendererElement, ExtraProps = {
    [key: string]: any;
}> {
    /**
     * @internal
     */
    __v_isVNode: true;
    /**
     * @internal
     */
    [ReactiveFlags.SKIP]: true;
    type: VNodeTypes;
    props: (VNodeProps & ExtraProps) | null;
    key: string | number | null;
    ref: VNodeNormalizedRef | null;
    scopeId: string | null;
    children: VNodeNormalizedChildren;
    component: ComponentInternalInstance | null;
    dirs: DirectiveBinding[] | null;
    transition: TransitionHooks<HostElement> | null;
    el: HostNode | null;
    anchor: HostNode | null;
    target: HostElement | null;
    targetAnchor: HostNode | null;
    staticCount: number;
    suspense: SuspenseBoundary | null;
    ssContent: VNode | null;
    ssFallback: VNode | null;
    shapeFlag: number;
    patchFlag: number;
    dynamicProps: string[] | null;
    dynamicChildren: VNode[] | null;
    appContext: AppContext | null;
}
export declare const blockStack: (VNode[] | null)[];
/**
 * Open a block.
 * This must be called before `createBlock`. It cannot be part of `createBlock`
 * because the children of the block are evaluated before `createBlock` itself
 * is called. The generated code typically looks like this:
 *
 * ```js
 * function render() {
 *   return (openBlock(),createBlock('div', null, [...]))
 * }
 * ```
 * disableTracking is true when creating a v-for fragment block, since a v-for
 * fragment always diffs its children.
 *
 * @private
 */
export declare function openBlock(disableTracking?: boolean): void;
export declare function closeBlock(): void;
/**
 * Block tracking sometimes needs to be disabled, for example during the
 * creation of a tree that needs to be cached by v-once. The compiler generates
 * code like this:
 *
 * ``` js
 * _cache[1] || (
 *   setBlockTracking(-1),
 *   _cache[1] = createVNode(...),
 *   setBlockTracking(1),
 *   _cache[1]
 * )
 * ```
 *
 * @private
 */
export declare function setBlockTracking(value: number): void;
/**
 * Create a block root vnode. Takes the same exact arguments as `createVNode`.
 * A block root keeps track of dynamic nodes within the block in the
 * `dynamicChildren` array.
 *
 * @private
 */
export declare function createBlock(type: VNodeTypes | ClassComponent, props?: Record<string, any> | null, children?: any, patchFlag?: number, dynamicProps?: string[]): VNode;
export declare function isVNode(value: any): value is VNode;
export declare function isSameVNodeType(n1: VNode, n2: VNode): boolean;
declare let vnodeArgsTransformer: ((args: Parameters<typeof _createVNode>, instance: ComponentInternalInstance | null) => Parameters<typeof _createVNode>) | undefined;
/**
 * Internal API for registering an arguments transform for createVNode
 * used for creating stubs in the test-utils
 * It is *internal* but needs to be exposed for test-utils to pick up proper
 * typings
 */
export declare function transformVNodeArgs(transformer?: typeof vnodeArgsTransformer): void;
export declare const InternalObjectKey = "__vInternal";
export declare const createVNode: typeof _createVNode;
declare function _createVNode(type: VNodeTypes | ClassComponent | typeof NULL_DYNAMIC_COMPONENT, props?: (Data & VNodeProps) | null, children?: unknown, patchFlag?: number, dynamicProps?: string[] | null, isBlockNode?: boolean): VNode;
export declare function cloneVNode<T, U>(vnode: VNode<T, U>, extraProps?: Data & VNodeProps | null, mergeRef?: boolean): VNode<T, U>;
/**
 * @private
 */
export declare function createTextVNode(text?: string, flag?: number): VNode;
/**
 * @private
 */
export declare function createStaticVNode(content: string, numberOfNodes: number): VNode;
/**
 * @private
 */
export declare function createCommentVNode(text?: string, asBlock?: boolean): VNode;
export declare function normalizeVNode(child: VNodeChild): VNode;
export declare function cloneIfMounted(child: VNode): VNode;
export declare function normalizeChildren(vnode: VNode, children: unknown): void;
/**
 * 在vue生成ssr时会用到（对atom-flutter没用），在cloneVNode时会用到
 * @param args
 */
export declare function mergeProps(...args: (Data & VNodeProps)[]): Record<string, unknown> & VNodeProps;
export {};
//# sourceMappingURL=vnode.d.ts.map