export declare const enum NodeTypes {
    TEXT = "text",
    ELEMENT = "element",
    COMMENT = "comment"
}
export declare const enum NodeOpTypes {
    CREATE = "create",
    INSERT = "insert",
    REMOVE = "remove",
    SET_TEXT = "setText",
    SET_ELEMENT_TEXT = "setElementText",
    PATCH = "patch"
}
export interface TestElement {
    id: number;
    type: NodeTypes.ELEMENT;
    parentNode: TestElement | null;
    tag: string;
    children: TestNode[];
    props: Record<string, any>;
    eventListeners: Record<string, Function | Function[]> | null;
}
export interface TestText {
    id: number;
    type: NodeTypes.TEXT;
    parentNode: TestElement | null;
    text: string;
}
export interface TestComment {
    id: number;
    type: NodeTypes.COMMENT;
    parentNode: TestElement | null;
    text: string;
}
export declare type TestNode = TestElement | TestText | TestComment;
export interface NodeOp {
    type: NodeOpTypes;
    nodeType?: NodeTypes;
    tag?: string;
    text?: string;
    targetNode?: TestNode;
    parentNode?: TestElement;
    refNode?: TestNode | null;
    propKey?: string;
    propPrevValue?: any;
    propNextValue?: any;
}
export declare function logNodeOp(op: NodeOp): void;
export declare function resetOps(): void;
export declare function dumpOps(): NodeOp[];
declare function createElement(tag: string): TestElement;
declare function createText(text: string): TestText;
declare function createComment(text: string): TestComment;
declare function setText(node: TestText, text: string): void;
declare function insert(child: TestNode, parent: TestElement, ref?: TestNode | null): void;
declare function remove(child: TestNode, logOp?: boolean): void;
declare function setElementText(el: TestElement, text: string): void;
declare function parentNode(node: TestNode): TestElement | null;
declare function nextSibling(node: TestNode): TestNode | null;
declare function querySelector(): any;
declare function setScopeId(el: TestElement, id: string): void;
export declare const nodeOps: {
    insert: typeof insert;
    remove: typeof remove;
    createElement: typeof createElement;
    createText: typeof createText;
    createComment: typeof createComment;
    setText: typeof setText;
    setElementText: typeof setElementText;
    parentNode: typeof parentNode;
    nextSibling: typeof nextSibling;
    querySelector: typeof querySelector;
    setScopeId: typeof setScopeId;
};
export {};
//# sourceMappingURL=nodeOps.d.ts.map